# funfedi_connect

funfedi_connect provides python methods to test and
interact with the containers from [containers.funfedi.dev](https://containers.funfedi.dev).

## Supported applications

--8<-- "./snippets/applications.md"

